@@ -7,7 +7,7 @@ task3_id = 'e82a250f-536f-4649-b3e2-2e8680a9119d' # Begin documenting your exper
 # test_model_presence
 # test_readme_presence
 
-if 'milesone_1.txt' in os.listdir('.'):
+if 'milestone_1.txt' in os.listdir('.'):
     errors = get_errors_fails('milestone_1.txt')
 
 
