@@ -7,28 +7,16 @@ task3_id = 'c1dfcdc5-97a4-4780-ab07-a0c4b785fcd2' # Create a function to simulat
 task4_id = 'bd6076ef-ac2e-45a1-b38c-b5b1d733f63c' # Update your documentation
 
 # def test_manual_rps_presence
-# def test_presence_readme
 
-if 'milesone_3_p1.txt' in os.listdir('.'):
-    errors = get_errors_fails('milesone_3_p1.txt')
+if 'milestone_3_p1.txt' in os.listdir('.'):
+    errors = get_errors_fails('milestone_3_p1.txt')
 
-
-    # If there are no errors, mark everything as complete
-    if 'test_presence_readme' in errors:
-        mark_incomplete(task4_id)
-        print(errors['test_presence_readme'])
-    else:
-        mark_complete(task4_id)
-    # Check if keras_model.h5 is in the repo
     if 'test_manual_rps_presence' in errors:
         # mark_incomplete(task2_id, message=errors['test_model_presence'])
-        mark_incomplete(task1_id)
+        mark_incomplete(task1_id, errors['test_manual_rps_presence'])
         mark_incomplete(task2_id)
-        print(errors['test_model_presence'])
-    # Check if there is a README.md file
-    if 'test_presence_readme' in errors:
         mark_incomplete(task3_id)
-        print(errors['test_presence_readme'])
+        mark_incomplete(task4_id)
 
 else:
     mark_incomplete(task1_id)
